summaryrefslogtreecommitdiffstats
path: root/jenkins_jobs/modules/project_maven.py
diff options
context:
space:
mode:
authorDavid Pursehouse <david.pursehouse@sonymobile.com>2014-06-20 11:41:40 +0900
committerDavid Pursehouse <david.pursehouse@sonymobile.com>2014-06-20 11:41:40 +0900
commit731615c9f94dee10c0ef4641591e48f939231ed3 (patch)
treeec4af4bd2b4d444ecbb1154bb5cd3c9aea7a517e /jenkins_jobs/modules/project_maven.py
parent463c84f0556ea78d429e36bdf158cf6bb1e3f390 (diff)
downloadpython-jenkins-job-builder-731615c9f94dee10c0ef4641591e48f939231ed3.tar.gz
python-jenkins-job-builder-731615c9f94dee10c0ef4641591e48f939231ed3.tar.xz
python-jenkins-job-builder-731615c9f94dee10c0ef4641591e48f939231ed3.zip
Consistency updates in documentation
Change-Id: I0096348488371c37c0ba645f0bd3d385975ef7d2
Diffstat (limited to 'jenkins_jobs/modules/project_maven.py')
-rwxr-xr-xjenkins_jobs/modules/project_maven.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/jenkins_jobs/modules/project_maven.py b/jenkins_jobs/modules/project_maven.py
index 138f16fa..e463eb9e 100755
--- a/jenkins_jobs/modules/project_maven.py
+++ b/jenkins_jobs/modules/project_maven.py
@@ -24,7 +24,7 @@ in the :ref:`Job` definition.
* **root-module**:
* **group-id** (`str`): GroupId.
* **artifact-id** (`str`): ArtifactId.
* **root-pom** (`str`): The path to the pom.xml file. (defaults to pom.xml)
* **goals** (`str`): Goals to execute. (required)
* **maven-opts** (`str`): Java options to pass to maven (aka MAVEN_OPTS)
* **maven-name** (`str`): Installation of maven which should be used.
@@ -34,9 +34,9 @@ in the :ref:`Job` definition.
Possible values are `default`, `local-to-workspace` and
`local-to-executor`.
* **ignore-upstream-changes** (`bool`): Do not start a build whenever
- a SNAPSHOT dependency is built or not. (defaults to true)
+ a SNAPSHOT dependency is built or not. (default true)
* **automatic-archiving** (`bool`): Activate automatic artifact archiving
- (defaults to true).
+ (default true).
* **settings** (`str`): Path to custom maven settings file (optional)
* **global-settings** (`str`): Path to custom maven global settings file
(optional)
@@ -24,7 +24,7 @@ in the :ref:`Job` definition.
* **group-id** (`str`): GroupId.
* **artifact-id** (`str`): ArtifactId.
- * **root-pom** (`str`): The path to the pom.xml file. (defaults to pom.xml)
+ * **root-pom** (`str`): The path to the pom.xml file. (default 'pom.xml')
* **goals** (`str`): Goals to execute. (required)
* **maven-opts** (`str`): Java options to pass to maven (aka MAVEN_OPTS)